netapp_ontap.resources.configuration_backup API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.configuration_backup`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API retrieves the current settings for the configuration and updates configuration backup settings. The GET operation retrieves the current settings for the configuration and the PATCH operation updates the configuration backup settings.

## Examples

These examples show how to retrieve and update the configuration backup settings.

### Retrieving the configuration backup settings

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConfigurationBackup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConfigurationBackup()
        resource.get()
        print(resource)

Try it out

    ConfigurationBackup({"url": "http://10.224.65.198/backups", "username": "me"})

### Updating the configuration backup settings

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ConfigurationBackup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ConfigurationBackup()
        resource.patch()

## Classes

`class ConfigurationBackup (*args, **kwargs)`

  Allows interaction with ConfigurationBackup objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the cluster configuration backup information.

    ### Learn more

    - `DOC /support/configuration-backup`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the cluster configuration backup information.

    ### Learn more

    - `DOC /support/configuration-backup`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ConfigurationBackupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ConfigurationBackup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `password PATCH`

    The password field of the configuration_backup.

    Example: yourpassword

  `url GET POST PATCH`

    An external backup location for the cluster configuration. This is mostly required for single node clusters where node and cluster configuration backups cannot be copied to other nodes in the cluster.

    Example: http://10.224.65.198/backups

  `username GET POST PATCH`

    The username field of the configuration_backup.

    Example: me

  `validate_certificate GET POST PATCH`

    Use this parameter with the value "true" to validate the digital certificate of the remote server. Digital certificate validation is available only when the HTTPS protocol is used in the URL; it is disabled by default.